%define major 0
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:           topcom
Version:        0.17.8
Release:        %mkrel 5
Group:          Development/C
Summary:        Triangulations Of Point Configurations and Oriented Matroids

License:        GPLv2+
URL:            https://www.rambau.wm.uni-bayreuth.de/TOPCOM/
Source0:        https://www.rambau.wm.uni-bayreuth.de/Software/TOPCOM-%{version}.tar.gz
# Man pages, written by Jerry James using text from the sources.  Therefore,
# these man pages have the same copyright and license as the sources.
Source1:        TOPCOM-man.tar.xz
# A replacement Makefile.  See the %%build section for more information.
Source2:        TOPCOM-Makefile

BuildRequires:  cddlib-devel
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  gmpxx-devel

Obsoletes:	TOPCOM < 0.17.8-3

%global topcom_major $(echo %{version} | cut -d. -f1)
%global topcom_minor $(echo %{version} | cut -d. -f2)

%description
TOPCOM is a package for computing Triangulations Of Point Configurations
and Oriented Matroids.  It was very much inspired by the maple program
PUNTOS, which was written by Jesus de Loera.  TOPCOM is entirely written
in C++, so there is a significant speed up compared to PUNTOS.

%package -n %{libname}
Summary:        Core TOPCOM functionality in a library
Obsoletes:	%{_lib}TOPCOM0 < 0.17.8-3

%description -n %{libname}
TOPCOM is a package for computing Triangulations Of Point Configurations
and Oriented Matroids.  It was very much inspired by the maple program
PUNTOS, which was written by Jesus de Loera.  TOPCOM is entirely written
in C++, so there is a significant speed up compared to PUNTOS.

%package -n %{develname}
Summary:        Header files needed to build with TOPCOM
Requires:       %{libname} = %{version}-%{release}
Obsoletes:	%{_lib}TOPCOM-devel < 0.17.8-3

%description -n %{develname}
Header files needed to build applications that use the TOPCOM library.

%package examples
Summary:        Example inputs and outputs for TOPCOM
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch
Obsoletes:	TOPCOM-examples < 0.17.8-3

%description examples
Example input and output files for TOPCOM.

%prep
%setup -q -a1

# Fix character encoding
iconv -f iso8859-1 -t utf8 -o README.utf8 README
touch -r README README.utf8
mv -f README.utf8 README

# Mimic upstream's modification of gmpxx.h, using the system gmpxx.h
mkdir -p external/include
sed "s|// \(q\.canonicalize\)|\1|" %{_includedir}/gmpxx.h > \
  external/include/gmpxx.h

%build
# We cannot use upstream's build system.  It has the following problems.
# (1) It builds two static libraries, libTOPCOM.a and libCHECKREG.a, then
#     includes both libraries in each of the 38 binaries that it installs in
#     %%{_bindir}.
# (2) Each of libTOPCOM.a and libCHECKREG.a refers to symbols defined by the
#     other.
# (3) It builds static gmp and cddlib libraries, which are also linked into
#     all of the constructed binaries.  There is no way to make it use the
#     installed versions of those libraries instead.
# We could fix (3) with a little build system hackery.  We could fix (1) by
# building shared libraries, but that doesn't help with (2).  Instead, we pull
# in our own evilly constructed Makefile to build a single shared library
# containing all of the object files in both libTOPCOM.a and libCHECKREG.a,
# and link the binaries against that and the system gmp and cddlib libraries.
sed -e "s|@RPM_OPT_FLAGS@|${RPM_OPT_FLAGS}|" \
    -e "s|@RPM_LD_FLAGS@|${RPM_LD_FLAGS}|" \
    -e "s|@bindir@|%{_bindir}|" \
    -e "s|@libdir@|%{_libdir}|" \
    -e "s|@mandir@|%{_mandir}|" \
    -e "s|@includedir@|%{_includedir}|" \
    -e "s|@version@|%{version}|" \
    -e "s|@major@|%{topcom_major}|" \
    -e "s|@minor@|%{topcom_minor}|" \
    -e "s|#version#|@version@|" \
    %{SOURCE2} > Makefile
%make_build

%install
%make_install

# Get rid of the Makefiles in the examples dir before packaging
rm -f examples/Makefile*

# Rename binaries with common names
for bin in cross cube cyclic hypersimplex lattice; do
  mv $RPM_BUILD_ROOT%{_bindir}/$bin $RPM_BUILD_ROOT%{_bindir}/TOPCOM-$bin
done

%files
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man7/*

%files -n %{develname}
%{_includedir}/TOPCOM/
%{_libdir}/*.so

%files -n %{libname}
%doc AUTHORS ChangeLog README
%license COPYING
%{_libdir}/*.so.%{major}{,.*}

%files examples
%doc examples


%changelog
* Thu Jun 26 2025 umeabot <umeabot> 0.17.8-5.mga10
+ Revision: 2196483
- Mageia 10 Mass Rebuild

* Fri Mar 18 2022 umeabot <umeabot> 0.17.8-4.mga9
+ Revision: 1798752
- Mageia 9 Mass Rebuild

* Sat Jul 31 2021 wally <wally> 0.17.8-3.mga9
+ Revision: 1738268
- rename as topcom

* Sat Feb 15 2020 umeabot <umeabot> 0.17.8-2.mga8
+ Revision: 1523575
- Mageia 8 Mass Rebuild

* Sat Mar 09 2019 shlomif <shlomif> 0.17.8-1.mga7
+ Revision: 1373366
- import from fedora

